psychopy_ext.exp.signal_det — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.signal_det

`psychopy_ext.exp.` `signal_det`(corr_resp, subj_resp)

  Returns an accuracy label according the (modified) Signal Detection Theory.

  Stimulus present | correct / incorrect | miss
  Stimulus absent | false alarm | (empty string)

  Args: | corr_resp What one should have responded. If no response expected (e.g., no stimulus present), then it should be an empty string (‘’) subj_resp What the observer responsed. If no response, it should be an empty string (‘’).
  Returns: | A string indicating the type of response.